@@ -71,10 +71,10 @@ class PKMClient(object):
 
         print(f"response: {http_code}, '{resp.headers}', '{resp.text[:100]}…'",
               file=sys.stderr)
-        answer = ''
+        answer = ""
 
         if http_code < 300:
-            STATUS = 0
+            status = 0
             if ('Content-Type' in resp.headers
                     and 'application/json' in resp.headers['Content-Type']):
                 answer = resp.json()
@@ -83,24 +83,22 @@ class PKMClient(object):
                              f"{resp.headers}, {resp.text}")
             print(error_message, file=sys.stderr)
             answer = error_message
-            STATUS = http_code
+            status = http_code
 
-        return STATUS, answer
+        return status, answer
 
     def login(self, user_name, user_password):
         # print(f"PKMClient.login {user_name}/***", file=sys.stderr)
 
-        status, USER_KEY = self.call(method='POST',
+        status, user_key = self.call(method='POST',
                                      path="user/login",
                                      payload={"user_name": user_name,
                                               "user_password": user_password})
         if status != 0:
-            print("user's login failed", file=sys.stderr)
+            print(f"user's login failed. answer: {user_key}", file=sys.stderr)
             return False
 
-        USER_KEY = USER_KEY['key']
-
-        self.key = USER_KEY
+        self.key = user_key['key']
         return True
 
     def now(self):
@@ -140,9 +138,14 @@ class PKMClient(object):
                   f"PKM answered status {getSt}", file=sys.stderr)
             print("Will try to put a new one.", file=sys.stderr)
             inv = invocationUpdate
+        elif type(getTx) != dict:
+            print(f"Data retrieved from PKM at {path} with status {getSt} is not a "
+                  f"dictionary: {getTx}", file=sys.stderr)
+            print("Will try to put a new one.", file=sys.stderr)
+            inv = invocationUpdate
         else:
             print(getSt, getTx, file=sys.stderr)
-            inv = json.loads(getTx)
+            inv = getTx
             inv.update(invocationUpdate)
         return self.call(method='PUT', path='invocations/'+project_id,
                          payload=json.dumps([inv]))
@@ -183,7 +186,7 @@ class Log(object):
             print(f"Logging {self.json()} failed with {status}: {result}",
                   file=sys.stderr)
         elif self.invocation_id is not None:
-            newLogID = json.loads(result)[0]
+            newLogID = result[0]
             self.pkm.update_invocation(
                 self.project, self.invocation_id, status,
                 dict(path=f"log/{self.project}"+str(newLogID), type="log"))
